# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common get_config new_operation new_request send_request
#' @include elbv2_service.R
NULL

#' Adds the specified SSL server certificate to the certificate list for
#' the specified HTTPS or TLS listener
#'
#' Adds the specified SSL server certificate to the certificate list for
#' the specified HTTPS or TLS listener.
#' 
#' If the certificate in already in the certificate list, the call is
#' successful but the certificate is not added again.
#' 
#' To get the certificate list for a listener, use
#' DescribeListenerCertificates. To remove certificates from the
#' certificate list for a listener, use RemoveListenerCertificates. To
#' replace the default certificate for a listener, use ModifyListener.
#' 
#' For more information, see [SSL
#' Certificates](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/create-https-listener.html#https-listener-certificates)
#' in the *Application Load Balancers Guide*.
#'
#' @usage
#' elbv2_add_listener_certificates(ListenerArn, Certificates)
#'
#' @param ListenerArn &#91;required&#93; The Amazon Resource Name (ARN) of the listener.
#' @param Certificates &#91;required&#93; The certificate to add. You can specify one certificate per call. Set
#' `CertificateArn` to the certificate ARN but do not set `IsDefault`.
#'
#' @section Request syntax:
#' ```
#' svc$add_listener_certificates(
#'   ListenerArn = "string",
#'   Certificates = list(
#'     list(
#'       CertificateArn = "string",
#'       IsDefault = TRUE|FALSE
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname elbv2_add_listener_certificates
elbv2_add_listener_certificates <- function(ListenerArn, Certificates) {
  op <- new_operation(
    name = "AddListenerCertificates",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$add_listener_certificates_input(ListenerArn = ListenerArn, Certificates = Certificates)
  output <- .elbv2$add_listener_certificates_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$add_listener_certificates <- elbv2_add_listener_certificates

#' Adds the specified tags to the specified Elastic Load Balancing resource
#'
#' Adds the specified tags to the specified Elastic Load Balancing
#' resource. You can tag your Application Load Balancers, Network Load
#' Balancers, and your target groups.
#' 
#' Each tag consists of a key and an optional value. If a resource already
#' has a tag with the same key, `AddTags` updates its value.
#' 
#' To list the current tags for your resources, use DescribeTags. To remove
#' tags from your resources, use RemoveTags.
#'
#' @usage
#' elbv2_add_tags(ResourceArns, Tags)
#'
#' @param ResourceArns &#91;required&#93; The Amazon Resource Name (ARN) of the resource.
#' @param Tags &#91;required&#93; The tags. Each resource can have a maximum of 10 tags.
#'
#' @section Request syntax:
#' ```
#' svc$add_tags(
#'   ResourceArns = list(
#'     "string"
#'   ),
#'   Tags = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example adds the specified tags to the specified load balancer.
#' \donttest{svc$add_tags(
#'   ResourceArns = list(
#'     "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my-load-balancer/5..."
#'   ),
#'   Tags = list(
#'     list(
#'       Key = "project",
#'       Value = "lima"
#'     ),
#'     list(
#'       Key = "department",
#'       Value = "digital-media"
#'     )
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_add_tags
elbv2_add_tags <- function(ResourceArns, Tags) {
  op <- new_operation(
    name = "AddTags",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$add_tags_input(ResourceArns = ResourceArns, Tags = Tags)
  output <- .elbv2$add_tags_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$add_tags <- elbv2_add_tags

#' Creates a listener for the specified Application Load Balancer or
#' Network Load Balancer
#'
#' Creates a listener for the specified Application Load Balancer or
#' Network Load Balancer.
#' 
#' To update a listener, use ModifyListener. When you are finished with a
#' listener, you can delete it using DeleteListener. If you are finished
#' with both the listener and the load balancer, you can delete them both
#' using DeleteLoadBalancer.
#' 
#' This operation is idempotent, which means that it completes at most one
#' time. If you attempt to create multiple listeners with the same
#' settings, each call succeeds.
#' 
#' For more information, see [Listeners for Your Application Load
#' Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-listeners.html)
#' in the *Application Load Balancers Guide* and [Listeners for Your
#' Network Load
#' Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-listeners.html)
#' in the *Network Load Balancers Guide*.
#'
#' @usage
#' elbv2_create_listener(LoadBalancerArn, Protocol, Port, SslPolicy,
#'   Certificates, DefaultActions)
#'
#' @param LoadBalancerArn &#91;required&#93; The Amazon Resource Name (ARN) of the load balancer.
#' @param Protocol &#91;required&#93; The protocol for connections from clients to the load balancer. For
#' Application Load Balancers, the supported protocols are HTTP and HTTPS.
#' For Network Load Balancers, the supported protocols are TCP, TLS, UDP,
#' and TCP\\_UDP.
#' @param Port &#91;required&#93; The port on which the load balancer is listening.
#' @param SslPolicy \[HTTPS and TLS listeners\] The security policy that defines which
#' ciphers and protocols are supported. The default is the current
#' predefined security policy.
#' @param Certificates \[HTTPS and TLS listeners\] The default certificate for the listener.
#' You must provide exactly one certificate. Set `CertificateArn` to the
#' certificate ARN but do not set `IsDefault`.
#' 
#' To create a certificate list for the listener, use
#' AddListenerCertificates.
#' @param DefaultActions &#91;required&#93; The actions for the default rule. The rule must include one forward
#' action or one or more fixed-response actions.
#' 
#' If the action type is `forward`, you specify one or more target groups.
#' The protocol of the target group must be HTTP or HTTPS for an
#' Application Load Balancer. The protocol of the target group must be TCP,
#' TLS, UDP, or TCP\\_UDP for a Network Load Balancer.
#' 
#' \[HTTPS listeners\] If the action type is `authenticate-oidc`, you
#' authenticate users through an identity provider that is OpenID Connect
#' (OIDC) compliant.
#' 
#' \[HTTPS listeners\] If the action type is `authenticate-cognito`, you
#' authenticate users through the user pools supported by Amazon Cognito.
#' 
#' \[Application Load Balancer\] If the action type is `redirect`, you
#' redirect specified client requests from one URL to another.
#' 
#' \[Application Load Balancer\] If the action type is `fixed-response`,
#' you drop specified client requests and return a custom HTTP response.
#'
#' @section Request syntax:
#' ```
#' svc$create_listener(
#'   LoadBalancerArn = "string",
#'   Protocol = "HTTP"|"HTTPS"|"TCP"|"TLS"|"UDP"|"TCP_UDP",
#'   Port = 123,
#'   SslPolicy = "string",
#'   Certificates = list(
#'     list(
#'       CertificateArn = "string",
#'       IsDefault = TRUE|FALSE
#'     )
#'   ),
#'   DefaultActions = list(
#'     list(
#'       Type = "forward"|"authenticate-oidc"|"authenticate-cognito"|"redirect"|"fixed-response",
#'       TargetGroupArn = "string",
#'       AuthenticateOidcConfig = list(
#'         Issuer = "string",
#'         AuthorizationEndpoint = "string",
#'         TokenEndpoint = "string",
#'         UserInfoEndpoint = "string",
#'         ClientId = "string",
#'         ClientSecret = "string",
#'         SessionCookieName = "string",
#'         Scope = "string",
#'         SessionTimeout = 123,
#'         AuthenticationRequestExtraParams = list(
#'           "string"
#'         ),
#'         OnUnauthenticatedRequest = "deny"|"allow"|"authenticate",
#'         UseExistingClientSecret = TRUE|FALSE
#'       ),
#'       AuthenticateCognitoConfig = list(
#'         UserPoolArn = "string",
#'         UserPoolClientId = "string",
#'         UserPoolDomain = "string",
#'         SessionCookieName = "string",
#'         Scope = "string",
#'         SessionTimeout = 123,
#'         AuthenticationRequestExtraParams = list(
#'           "string"
#'         ),
#'         OnUnauthenticatedRequest = "deny"|"allow"|"authenticate"
#'       ),
#'       Order = 123,
#'       RedirectConfig = list(
#'         Protocol = "string",
#'         Port = "string",
#'         Host = "string",
#'         Path = "string",
#'         Query = "string",
#'         StatusCode = "HTTP_301"|"HTTP_302"
#'       ),
#'       FixedResponseConfig = list(
#'         MessageBody = "string",
#'         StatusCode = "string",
#'         ContentType = "string"
#'       ),
#'       ForwardConfig = list(
#'         TargetGroups = list(
#'           list(
#'             TargetGroupArn = "string",
#'             Weight = 123
#'           )
#'         ),
#'         TargetGroupStickinessConfig = list(
#'           Enabled = TRUE|FALSE,
#'           DurationSeconds = 123
#'         )
#'       )
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example creates an HTTP listener for the specified load balancer
#' # that forwards requests to the specified target group.
#' \donttest{svc$create_listener(
#'   DefaultActions = list(
#'     list(
#'       TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-t...",
#'       Type = "forward"
#'     )
#'   ),
#'   LoadBalancerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my...",
#'   Port = 80L,
#'   Protocol = "HTTP"
#' )}
#' 
#' # This example creates an HTTPS listener for the specified load balancer
#' # that forwards requests to the specified target group. Note that you must
#' # specify an SSL certificate for an HTTPS listener. You can create and
#' # manage certificates using AWS Certificate Manager (ACM). Alternatively,
#' # you can create a certificate using SSL/TLS tools, get the certificate
#' # signed by a certificate authority (CA), and upload the certificate to
#' # AWS Identity and Access Management (IAM).
#' \donttest{svc$create_listener(
#'   Certificates = list(
#'     list(
#'       CertificateArn = "arn:aws:iam::123456789012:server-certificate/my-server-cert"
#'     )
#'   ),
#'   DefaultActions = list(
#'     list(
#'       TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-t...",
#'       Type = "forward"
#'     )
#'   ),
#'   LoadBalancerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my...",
#'   Port = 443L,
#'   Protocol = "HTTPS",
#'   SslPolicy = "ELBSecurityPolicy-2015-05"
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_create_listener
elbv2_create_listener <- function(LoadBalancerArn, Protocol, Port, SslPolicy = NULL, Certificates = NULL, DefaultActions) {
  op <- new_operation(
    name = "CreateListener",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$create_listener_input(LoadBalancerArn = LoadBalancerArn, Protocol = Protocol, Port = Port, SslPolicy = SslPolicy, Certificates = Certificates, DefaultActions = DefaultActions)
  output <- .elbv2$create_listener_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$create_listener <- elbv2_create_listener

#' Creates an Application Load Balancer or a Network Load Balancer
#'
#' Creates an Application Load Balancer or a Network Load Balancer.
#' 
#' When you create a load balancer, you can specify security groups, public
#' subnets, IP address type, and tags. Otherwise, you could do so later
#' using SetSecurityGroups, SetSubnets, SetIpAddressType, and AddTags.
#' 
#' To create listeners for your load balancer, use CreateListener. To
#' describe your current load balancers, see DescribeLoadBalancers. When
#' you are finished with a load balancer, you can delete it using
#' DeleteLoadBalancer.
#' 
#' For limit information, see [Limits for Your Application Load
#' Balancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-limits.html)
#' in the *Application Load Balancers Guide* and [Limits for Your Network
#' Load
#' Balancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-limits.html)
#' in the *Network Load Balancers Guide*.
#' 
#' This operation is idempotent, which means that it completes at most one
#' time. If you attempt to create multiple load balancers with the same
#' settings, each call succeeds.
#' 
#' For more information, see [Application Load
#' Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/application-load-balancers.html)
#' in the *Application Load Balancers Guide* and [Network Load
#' Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/network-load-balancers.html)
#' in the *Network Load Balancers Guide*.
#'
#' @usage
#' elbv2_create_load_balancer(Name, Subnets, SubnetMappings,
#'   SecurityGroups, Scheme, Tags, Type, IpAddressType)
#'
#' @param Name &#91;required&#93; The name of the load balancer.
#' 
#' This name must be unique per region per account, can have a maximum of
#' 32 characters, must contain only alphanumeric characters or hyphens,
#' must not begin or end with a hyphen, and must not begin with
#' \"internal-\".
#' @param Subnets The IDs of the public subnets. You can specify only one subnet per
#' Availability Zone. You must specify either subnets or subnet mappings.
#' 
#' \[Application Load Balancers\] You must specify subnets from at least
#' two Availability Zones.
#' 
#' \[Network Load Balancers\] You can specify subnets from one or more
#' Availability Zones.
#' @param SubnetMappings The IDs of the public subnets. You can specify only one subnet per
#' Availability Zone. You must specify either subnets or subnet mappings.
#' 
#' \[Application Load Balancers\] You must specify subnets from at least
#' two Availability Zones. You cannot specify Elastic IP addresses for your
#' subnets.
#' 
#' \[Network Load Balancers\] You can specify subnets from one or more
#' Availability Zones. You can specify one Elastic IP address per subnet if
#' you need static IP addresses for your internet-facing load balancer. For
#' internal load balancers, you can specify one private IP address per
#' subnet from the IPv4 range of the subnet.
#' @param SecurityGroups \[Application Load Balancers\] The IDs of the security groups for the
#' load balancer.
#' @param Scheme The nodes of an Internet-facing load balancer have public IP addresses.
#' The DNS name of an Internet-facing load balancer is publicly resolvable
#' to the public IP addresses of the nodes. Therefore, Internet-facing load
#' balancers can route requests from clients over the internet.
#' 
#' The nodes of an internal load balancer have only private IP addresses.
#' The DNS name of an internal load balancer is publicly resolvable to the
#' private IP addresses of the nodes. Therefore, internal load balancers
#' can route requests only from clients with access to the VPC for the load
#' balancer.
#' 
#' The default is an Internet-facing load balancer.
#' @param Tags One or more tags to assign to the load balancer.
#' @param Type The type of load balancer. The default is `application`.
#' @param IpAddressType \[Application Load Balancers\] The type of IP addresses used by the
#' subnets for your load balancer. The possible values are `ipv4` (for IPv4
#' addresses) and `dualstack` (for IPv4 and IPv6 addresses). Internal load
#' balancers must use `ipv4`.
#'
#' @section Request syntax:
#' ```
#' svc$create_load_balancer(
#'   Name = "string",
#'   Subnets = list(
#'     "string"
#'   ),
#'   SubnetMappings = list(
#'     list(
#'       SubnetId = "string",
#'       AllocationId = "string",
#'       PrivateIPv4Address = "string"
#'     )
#'   ),
#'   SecurityGroups = list(
#'     "string"
#'   ),
#'   Scheme = "internet-facing"|"internal",
#'   Tags = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   ),
#'   Type = "application"|"network",
#'   IpAddressType = "ipv4"|"dualstack"
#' )
#' ```
#'
#' @examples
#' # This example creates an Internet-facing load balancer and enables the
#' # Availability Zones for the specified subnets.
#' \donttest{svc$create_load_balancer(
#'   Name = "my-load-balancer",
#'   Subnets = list(
#'     "subnet-b7d581c0",
#'     "subnet-8360a9e7"
#'   )
#' )}
#' 
#' # This example creates an internal load balancer and enables the
#' # Availability Zones for the specified subnets.
#' \donttest{svc$create_load_balancer(
#'   Name = "my-internal-load-balancer",
#'   Scheme = "internal",
#'   SecurityGroups = list(),
#'   Subnets = list(
#'     "subnet-b7d581c0",
#'     "subnet-8360a9e7"
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_create_load_balancer
elbv2_create_load_balancer <- function(Name, Subnets = NULL, SubnetMappings = NULL, SecurityGroups = NULL, Scheme = NULL, Tags = NULL, Type = NULL, IpAddressType = NULL) {
  op <- new_operation(
    name = "CreateLoadBalancer",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$create_load_balancer_input(Name = Name, Subnets = Subnets, SubnetMappings = SubnetMappings, SecurityGroups = SecurityGroups, Scheme = Scheme, Tags = Tags, Type = Type, IpAddressType = IpAddressType)
  output <- .elbv2$create_load_balancer_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$create_load_balancer <- elbv2_create_load_balancer

#' Creates a rule for the specified listener
#'
#' Creates a rule for the specified listener. The listener must be
#' associated with an Application Load Balancer.
#' 
#' Rules are evaluated in priority order, from the lowest value to the
#' highest value. When the conditions for a rule are met, its actions are
#' performed. If the conditions for no rules are met, the actions for the
#' default rule are performed. For more information, see [Listener
#' Rules](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-listeners.html#listener-rules)
#' in the *Application Load Balancers Guide*.
#' 
#' To view your current rules, use DescribeRules. To update a rule, use
#' ModifyRule. To set the priorities of your rules, use SetRulePriorities.
#' To delete a rule, use DeleteRule.
#'
#' @usage
#' elbv2_create_rule(ListenerArn, Conditions, Priority, Actions)
#'
#' @param ListenerArn &#91;required&#93; The Amazon Resource Name (ARN) of the listener.
#' @param Conditions &#91;required&#93; The conditions. Each rule can include zero or one of the following
#' conditions: `http-request-method`, `host-header`, `path-pattern`, and
#' `source-ip`, and zero or more of the following conditions: `http-header`
#' and `query-string`.
#' @param Priority &#91;required&#93; The rule priority. A listener can\'t have multiple rules with the same
#' priority.
#' @param Actions &#91;required&#93; The actions. Each rule must include exactly one of the following types
#' of actions: `forward`, `fixed-response`, or `redirect`, and it must be
#' the last action to be performed.
#' 
#' If the action type is `forward`, you specify one or more target groups.
#' The protocol of the target group must be HTTP or HTTPS for an
#' Application Load Balancer. The protocol of the target group must be TCP,
#' TLS, UDP, or TCP\\_UDP for a Network Load Balancer.
#' 
#' \[HTTPS listeners\] If the action type is `authenticate-oidc`, you
#' authenticate users through an identity provider that is OpenID Connect
#' (OIDC) compliant.
#' 
#' \[HTTPS listeners\] If the action type is `authenticate-cognito`, you
#' authenticate users through the user pools supported by Amazon Cognito.
#' 
#' \[Application Load Balancer\] If the action type is `redirect`, you
#' redirect specified client requests from one URL to another.
#' 
#' \[Application Load Balancer\] If the action type is `fixed-response`,
#' you drop specified client requests and return a custom HTTP response.
#'
#' @section Request syntax:
#' ```
#' svc$create_rule(
#'   ListenerArn = "string",
#'   Conditions = list(
#'     list(
#'       Field = "string",
#'       Values = list(
#'         "string"
#'       ),
#'       HostHeaderConfig = list(
#'         Values = list(
#'           "string"
#'         )
#'       ),
#'       PathPatternConfig = list(
#'         Values = list(
#'           "string"
#'         )
#'       ),
#'       HttpHeaderConfig = list(
#'         HttpHeaderName = "string",
#'         Values = list(
#'           "string"
#'         )
#'       ),
#'       QueryStringConfig = list(
#'         Values = list(
#'           list(
#'             Key = "string",
#'             Value = "string"
#'           )
#'         )
#'       ),
#'       HttpRequestMethodConfig = list(
#'         Values = list(
#'           "string"
#'         )
#'       ),
#'       SourceIpConfig = list(
#'         Values = list(
#'           "string"
#'         )
#'       )
#'     )
#'   ),
#'   Priority = 123,
#'   Actions = list(
#'     list(
#'       Type = "forward"|"authenticate-oidc"|"authenticate-cognito"|"redirect"|"fixed-response",
#'       TargetGroupArn = "string",
#'       AuthenticateOidcConfig = list(
#'         Issuer = "string",
#'         AuthorizationEndpoint = "string",
#'         TokenEndpoint = "string",
#'         UserInfoEndpoint = "string",
#'         ClientId = "string",
#'         ClientSecret = "string",
#'         SessionCookieName = "string",
#'         Scope = "string",
#'         SessionTimeout = 123,
#'         AuthenticationRequestExtraParams = list(
#'           "string"
#'         ),
#'         OnUnauthenticatedRequest = "deny"|"allow"|"authenticate",
#'         UseExistingClientSecret = TRUE|FALSE
#'       ),
#'       AuthenticateCognitoConfig = list(
#'         UserPoolArn = "string",
#'         UserPoolClientId = "string",
#'         UserPoolDomain = "string",
#'         SessionCookieName = "string",
#'         Scope = "string",
#'         SessionTimeout = 123,
#'         AuthenticationRequestExtraParams = list(
#'           "string"
#'         ),
#'         OnUnauthenticatedRequest = "deny"|"allow"|"authenticate"
#'       ),
#'       Order = 123,
#'       RedirectConfig = list(
#'         Protocol = "string",
#'         Port = "string",
#'         Host = "string",
#'         Path = "string",
#'         Query = "string",
#'         StatusCode = "HTTP_301"|"HTTP_302"
#'       ),
#'       FixedResponseConfig = list(
#'         MessageBody = "string",
#'         StatusCode = "string",
#'         ContentType = "string"
#'       ),
#'       ForwardConfig = list(
#'         TargetGroups = list(
#'           list(
#'             TargetGroupArn = "string",
#'             Weight = 123
#'           )
#'         ),
#'         TargetGroupStickinessConfig = list(
#'           Enabled = TRUE|FALSE,
#'           DurationSeconds = 123
#'         )
#'       )
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example creates a rule that forwards requests to the specified
#' # target group if the URL contains the specified pattern (for example,
#' # /img/*).
#' \donttest{svc$create_rule(
#'   Actions = list(
#'     list(
#'       TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-t...",
#'       Type = "forward"
#'     )
#'   ),
#'   Conditions = list(
#'     list(
#'       Field = "path-pattern",
#'       Values = list(
#'         "/img/*"
#'       )
#'     )
#'   ),
#'   ListenerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:listener/app/my-load-ba...",
#'   Priority = 10L
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_create_rule
elbv2_create_rule <- function(ListenerArn, Conditions, Priority, Actions) {
  op <- new_operation(
    name = "CreateRule",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$create_rule_input(ListenerArn = ListenerArn, Conditions = Conditions, Priority = Priority, Actions = Actions)
  output <- .elbv2$create_rule_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$create_rule <- elbv2_create_rule

#' Creates a target group
#'
#' Creates a target group.
#' 
#' To register targets with the target group, use RegisterTargets. To
#' update the health check settings for the target group, use
#' ModifyTargetGroup. To monitor the health of targets in the target group,
#' use DescribeTargetHealth.
#' 
#' To route traffic to the targets in a target group, specify the target
#' group in an action using CreateListener or CreateRule.
#' 
#' To delete a target group, use DeleteTargetGroup.
#' 
#' This operation is idempotent, which means that it completes at most one
#' time. If you attempt to create multiple target groups with the same
#' settings, each call succeeds.
#' 
#' For more information, see [Target Groups for Your Application Load
#' Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-target-groups.html)
#' in the *Application Load Balancers Guide* or [Target Groups for Your
#' Network Load
#' Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-target-groups.html)
#' in the *Network Load Balancers Guide*.
#'
#' @usage
#' elbv2_create_target_group(Name, Protocol, Port, VpcId,
#'   HealthCheckProtocol, HealthCheckPort, HealthCheckEnabled,
#'   HealthCheckPath, HealthCheckIntervalSeconds, HealthCheckTimeoutSeconds,
#'   HealthyThresholdCount, UnhealthyThresholdCount, Matcher, TargetType)
#'
#' @param Name &#91;required&#93; The name of the target group.
#' 
#' This name must be unique per region per account, can have a maximum of
#' 32 characters, must contain only alphanumeric characters or hyphens, and
#' must not begin or end with a hyphen.
#' @param Protocol The protocol to use for routing traffic to the targets. For Application
#' Load Balancers, the supported protocols are HTTP and HTTPS. For Network
#' Load Balancers, the supported protocols are TCP, TLS, UDP, or TCP\\_UDP.
#' A TCP\\_UDP listener must be associated with a TCP\\_UDP target group. If
#' the target is a Lambda function, this parameter does not apply.
#' @param Port The port on which the targets receive traffic. This port is used unless
#' you specify a port override when registering the target. If the target
#' is a Lambda function, this parameter does not apply.
#' @param VpcId The identifier of the virtual private cloud (VPC). If the target is a
#' Lambda function, this parameter does not apply. Otherwise, this
#' parameter is required.
#' @param HealthCheckProtocol The protocol the load balancer uses when performing health checks on
#' targets. For Application Load Balancers, the default is HTTP. For
#' Network Load Balancers, the default is TCP. The TCP protocol is
#' supported for health checks only if the protocol of the target group is
#' TCP, TLS, UDP, or TCP\\_UDP. The TLS, UDP, and TCP\\_UDP protocols are not
#' supported for health checks.
#' @param HealthCheckPort The port the load balancer uses when performing health checks on
#' targets. The default is `traffic-port`, which is the port on which each
#' target receives traffic from the load balancer.
#' @param HealthCheckEnabled Indicates whether health checks are enabled. If the target type is
#' `lambda`, health checks are disabled by default but can be enabled. If
#' the target type is `instance` or `ip`, health checks are always enabled
#' and cannot be disabled.
#' @param HealthCheckPath \[HTTP/HTTPS health checks\] The ping path that is the destination on
#' the targets for health checks. The default is /.
#' @param HealthCheckIntervalSeconds The approximate amount of time, in seconds, between health checks of an
#' individual target. For HTTP and HTTPS health checks, the range is 5--300
#' seconds. For TCP health checks, the supported values are 10 and 30
#' seconds. If the target type is `instance` or `ip`, the default is 30
#' seconds. If the target type is `lambda`, the default is 35 seconds.
#' @param HealthCheckTimeoutSeconds The amount of time, in seconds, during which no response from a target
#' means a failed health check. For target groups with a protocol of HTTP
#' or HTTPS, the default is 5 seconds. For target groups with a protocol of
#' TCP or TLS, this value must be 6 seconds for HTTP health checks and 10
#' seconds for TCP and HTTPS health checks. If the target type is `lambda`,
#' the default is 30 seconds.
#' @param HealthyThresholdCount The number of consecutive health checks successes required before
#' considering an unhealthy target healthy. For target groups with a
#' protocol of HTTP or HTTPS, the default is 5. For target groups with a
#' protocol of TCP or TLS, the default is 3. If the target type is
#' `lambda`, the default is 5.
#' @param UnhealthyThresholdCount The number of consecutive health check failures required before
#' considering a target unhealthy. For target groups with a protocol of
#' HTTP or HTTPS, the default is 2. For target groups with a protocol of
#' TCP or TLS, this value must be the same as the healthy threshold count.
#' If the target type is `lambda`, the default is 2.
#' @param Matcher \[HTTP/HTTPS health checks\] The HTTP codes to use when checking for a
#' successful response from a target.
#' @param TargetType The type of target that you must specify when registering targets with
#' this target group. You can\'t specify targets for a target group using
#' more than one target type.
#' 
#' -   `instance` - Targets are specified by instance ID. This is the
#'     default value. If the target group protocol is UDP or TCP\\_UDP, the
#'     target type must be `instance`.
#' 
#' -   `ip` - Targets are specified by IP address. You can specify IP
#'     addresses from the subnets of the virtual private cloud (VPC) for
#'     the target group, the RFC 1918 range (10.0.0.0/8, 172.16.0.0/12, and
#'     192.168.0.0/16), and the RFC 6598 range (100.64.0.0/10). You can\'t
#'     specify publicly routable IP addresses.
#' 
#' -   `lambda` - The target groups contains a single Lambda function.
#'
#' @section Request syntax:
#' ```
#' svc$create_target_group(
#'   Name = "string",
#'   Protocol = "HTTP"|"HTTPS"|"TCP"|"TLS"|"UDP"|"TCP_UDP",
#'   Port = 123,
#'   VpcId = "string",
#'   HealthCheckProtocol = "HTTP"|"HTTPS"|"TCP"|"TLS"|"UDP"|"TCP_UDP",
#'   HealthCheckPort = "string",
#'   HealthCheckEnabled = TRUE|FALSE,
#'   HealthCheckPath = "string",
#'   HealthCheckIntervalSeconds = 123,
#'   HealthCheckTimeoutSeconds = 123,
#'   HealthyThresholdCount = 123,
#'   UnhealthyThresholdCount = 123,
#'   Matcher = list(
#'     HttpCode = "string"
#'   ),
#'   TargetType = "instance"|"ip"|"lambda"
#' )
#' ```
#'
#' @examples
#' # This example creates a target group that you can use to route traffic to
#' # targets using HTTP on port 80. This target group uses the default health
#' # check configuration.
#' \donttest{svc$create_target_group(
#'   Name = "my-targets",
#'   Port = 80L,
#'   Protocol = "HTTP",
#'   VpcId = "vpc-3ac0fb5f"
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_create_target_group
elbv2_create_target_group <- function(Name, Protocol = NULL, Port = NULL, VpcId = NULL, HealthCheckProtocol = NULL, HealthCheckPort = NULL, HealthCheckEnabled = NULL, HealthCheckPath = NULL, HealthCheckIntervalSeconds = NULL, HealthCheckTimeoutSeconds = NULL, HealthyThresholdCount = NULL, UnhealthyThresholdCount = NULL, Matcher = NULL, TargetType = NULL) {
  op <- new_operation(
    name = "CreateTargetGroup",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$create_target_group_input(Name = Name, Protocol = Protocol, Port = Port, VpcId = VpcId, HealthCheckProtocol = HealthCheckProtocol, HealthCheckPort = HealthCheckPort, HealthCheckEnabled = HealthCheckEnabled, HealthCheckPath = HealthCheckPath, HealthCheckIntervalSeconds = HealthCheckIntervalSeconds, HealthCheckTimeoutSeconds = HealthCheckTimeoutSeconds, HealthyThresholdCount = HealthyThresholdCount, UnhealthyThresholdCount = UnhealthyThresholdCount, Matcher = Matcher, TargetType = TargetType)
  output <- .elbv2$create_target_group_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$create_target_group <- elbv2_create_target_group

#' Deletes the specified listener
#'
#' Deletes the specified listener.
#' 
#' Alternatively, your listener is deleted when you delete the load
#' balancer to which it is attached, using DeleteLoadBalancer.
#'
#' @usage
#' elbv2_delete_listener(ListenerArn)
#'
#' @param ListenerArn &#91;required&#93; The Amazon Resource Name (ARN) of the listener.
#'
#' @section Request syntax:
#' ```
#' svc$delete_listener(
#'   ListenerArn = "string"
#' )
#' ```
#'
#' @examples
#' # This example deletes the specified listener.
#' \donttest{svc$delete_listener(
#'   ListenerArn = "arn:aws:elasticloadbalancing:ua-west-2:123456789012:listener/app/my-load-ba..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_delete_listener
elbv2_delete_listener <- function(ListenerArn) {
  op <- new_operation(
    name = "DeleteListener",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$delete_listener_input(ListenerArn = ListenerArn)
  output <- .elbv2$delete_listener_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$delete_listener <- elbv2_delete_listener

#' Deletes the specified Application Load Balancer or Network Load Balancer
#' and its attached listeners
#'
#' Deletes the specified Application Load Balancer or Network Load Balancer
#' and its attached listeners.
#' 
#' You can\'t delete a load balancer if deletion protection is enabled. If
#' the load balancer does not exist or has already been deleted, the call
#' succeeds.
#' 
#' Deleting a load balancer does not affect its registered targets. For
#' example, your EC2 instances continue to run and are still registered to
#' their target groups. If you no longer need these EC2 instances, you can
#' stop or terminate them.
#'
#' @usage
#' elbv2_delete_load_balancer(LoadBalancerArn)
#'
#' @param LoadBalancerArn &#91;required&#93; The Amazon Resource Name (ARN) of the load balancer.
#'
#' @section Request syntax:
#' ```
#' svc$delete_load_balancer(
#'   LoadBalancerArn = "string"
#' )
#' ```
#'
#' @examples
#' # This example deletes the specified load balancer.
#' \donttest{svc$delete_load_balancer(
#'   LoadBalancerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_delete_load_balancer
elbv2_delete_load_balancer <- function(LoadBalancerArn) {
  op <- new_operation(
    name = "DeleteLoadBalancer",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$delete_load_balancer_input(LoadBalancerArn = LoadBalancerArn)
  output <- .elbv2$delete_load_balancer_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$delete_load_balancer <- elbv2_delete_load_balancer

#' Deletes the specified rule
#'
#' Deletes the specified rule.
#'
#' @usage
#' elbv2_delete_rule(RuleArn)
#'
#' @param RuleArn &#91;required&#93; The Amazon Resource Name (ARN) of the rule.
#'
#' @section Request syntax:
#' ```
#' svc$delete_rule(
#'   RuleArn = "string"
#' )
#' ```
#'
#' @examples
#' # This example deletes the specified rule.
#' \donttest{svc$delete_rule(
#'   RuleArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:listener-rule/app/my-load-b..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_delete_rule
elbv2_delete_rule <- function(RuleArn) {
  op <- new_operation(
    name = "DeleteRule",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$delete_rule_input(RuleArn = RuleArn)
  output <- .elbv2$delete_rule_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$delete_rule <- elbv2_delete_rule

#' Deletes the specified target group
#'
#' Deletes the specified target group.
#' 
#' You can delete a target group if it is not referenced by any actions.
#' Deleting a target group also deletes any associated health checks.
#'
#' @usage
#' elbv2_delete_target_group(TargetGroupArn)
#'
#' @param TargetGroupArn &#91;required&#93; The Amazon Resource Name (ARN) of the target group.
#'
#' @section Request syntax:
#' ```
#' svc$delete_target_group(
#'   TargetGroupArn = "string"
#' )
#' ```
#'
#' @examples
#' # This example deletes the specified target group.
#' \donttest{svc$delete_target_group(
#'   TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targe..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_delete_target_group
elbv2_delete_target_group <- function(TargetGroupArn) {
  op <- new_operation(
    name = "DeleteTargetGroup",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$delete_target_group_input(TargetGroupArn = TargetGroupArn)
  output <- .elbv2$delete_target_group_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$delete_target_group <- elbv2_delete_target_group

#' Deregisters the specified targets from the specified target group
#'
#' Deregisters the specified targets from the specified target group. After
#' the targets are deregistered, they no longer receive traffic from the
#' load balancer.
#'
#' @usage
#' elbv2_deregister_targets(TargetGroupArn, Targets)
#'
#' @param TargetGroupArn &#91;required&#93; The Amazon Resource Name (ARN) of the target group.
#' @param Targets &#91;required&#93; The targets. If you specified a port override when you registered a
#' target, you must specify both the target ID and the port when you
#' deregister it.
#'
#' @section Request syntax:
#' ```
#' svc$deregister_targets(
#'   TargetGroupArn = "string",
#'   Targets = list(
#'     list(
#'       Id = "string",
#'       Port = 123,
#'       AvailabilityZone = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example deregisters the specified instance from the specified
#' # target group.
#' \donttest{svc$deregister_targets(
#'   TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targe...",
#'   Targets = list(
#'     list(
#'       Id = "i-0f76fade"
#'     )
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_deregister_targets
elbv2_deregister_targets <- function(TargetGroupArn, Targets) {
  op <- new_operation(
    name = "DeregisterTargets",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$deregister_targets_input(TargetGroupArn = TargetGroupArn, Targets = Targets)
  output <- .elbv2$deregister_targets_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$deregister_targets <- elbv2_deregister_targets

#' Describes the current Elastic Load Balancing resource limits for your
#' AWS account
#'
#' Describes the current Elastic Load Balancing resource limits for your
#' AWS account.
#' 
#' For more information, see [Limits for Your Application Load
#' Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-limits.html)
#' in the *Application Load Balancer Guide* or [Limits for Your Network
#' Load
#' Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-limits.html)
#' in the *Network Load Balancers Guide*.
#'
#' @usage
#' elbv2_describe_account_limits(Marker, PageSize)
#'
#' @param Marker The marker for the next set of results. (You received this marker from a
#' previous call.)
#' @param PageSize The maximum number of results to return with this call.
#'
#' @section Request syntax:
#' ```
#' svc$describe_account_limits(
#'   Marker = "string",
#'   PageSize = 123
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_account_limits
elbv2_describe_account_limits <- function(Marker = NULL, PageSize = NULL) {
  op <- new_operation(
    name = "DescribeAccountLimits",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_account_limits_input(Marker = Marker, PageSize = PageSize)
  output <- .elbv2$describe_account_limits_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_account_limits <- elbv2_describe_account_limits

#' Describes the default certificate and the certificate list for the
#' specified HTTPS or TLS listener
#'
#' Describes the default certificate and the certificate list for the
#' specified HTTPS or TLS listener.
#' 
#' If the default certificate is also in the certificate list, it appears
#' twice in the results (once with `IsDefault` set to true and once with
#' `IsDefault` set to false).
#' 
#' For more information, see [SSL
#' Certificates](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/create-https-listener.html#https-listener-certificates)
#' in the *Application Load Balancers Guide*.
#'
#' @usage
#' elbv2_describe_listener_certificates(ListenerArn, Marker, PageSize)
#'
#' @param ListenerArn &#91;required&#93; The Amazon Resource Names (ARN) of the listener.
#' @param Marker The marker for the next set of results. (You received this marker from a
#' previous call.)
#' @param PageSize The maximum number of results to return with this call.
#'
#' @section Request syntax:
#' ```
#' svc$describe_listener_certificates(
#'   ListenerArn = "string",
#'   Marker = "string",
#'   PageSize = 123
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_listener_certificates
elbv2_describe_listener_certificates <- function(ListenerArn, Marker = NULL, PageSize = NULL) {
  op <- new_operation(
    name = "DescribeListenerCertificates",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_listener_certificates_input(ListenerArn = ListenerArn, Marker = Marker, PageSize = PageSize)
  output <- .elbv2$describe_listener_certificates_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_listener_certificates <- elbv2_describe_listener_certificates

#' Describes the specified listeners or the listeners for the specified
#' Application Load Balancer or Network Load Balancer
#'
#' Describes the specified listeners or the listeners for the specified
#' Application Load Balancer or Network Load Balancer. You must specify
#' either a load balancer or one or more listeners.
#' 
#' For an HTTPS or TLS listener, the output includes the default
#' certificate for the listener. To describe the certificate list for the
#' listener, use DescribeListenerCertificates.
#'
#' @usage
#' elbv2_describe_listeners(LoadBalancerArn, ListenerArns, Marker,
#'   PageSize)
#'
#' @param LoadBalancerArn The Amazon Resource Name (ARN) of the load balancer.
#' @param ListenerArns The Amazon Resource Names (ARN) of the listeners.
#' @param Marker The marker for the next set of results. (You received this marker from a
#' previous call.)
#' @param PageSize The maximum number of results to return with this call.
#'
#' @section Request syntax:
#' ```
#' svc$describe_listeners(
#'   LoadBalancerArn = "string",
#'   ListenerArns = list(
#'     "string"
#'   ),
#'   Marker = "string",
#'   PageSize = 123
#' )
#' ```
#'
#' @examples
#' # This example describes the specified listener.
#' \donttest{svc$describe_listeners(
#'   ListenerArns = list(
#'     "arn:aws:elasticloadbalancing:us-west-2:123456789012:listener/app/my-load-balancer/50dc6..."
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_listeners
elbv2_describe_listeners <- function(LoadBalancerArn = NULL, ListenerArns = NULL, Marker = NULL, PageSize = NULL) {
  op <- new_operation(
    name = "DescribeListeners",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_listeners_input(LoadBalancerArn = LoadBalancerArn, ListenerArns = ListenerArns, Marker = Marker, PageSize = PageSize)
  output <- .elbv2$describe_listeners_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_listeners <- elbv2_describe_listeners

#' Describes the attributes for the specified Application Load Balancer or
#' Network Load Balancer
#'
#' Describes the attributes for the specified Application Load Balancer or
#' Network Load Balancer.
#' 
#' For more information, see [Load Balancer
#' Attributes](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/application-load-balancers.html#load-balancer-attributes)
#' in the *Application Load Balancers Guide* or [Load Balancer
#' Attributes](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/network-load-balancers.html#load-balancer-attributes)
#' in the *Network Load Balancers Guide*.
#'
#' @usage
#' elbv2_describe_load_balancer_attributes(LoadBalancerArn)
#'
#' @param LoadBalancerArn &#91;required&#93; The Amazon Resource Name (ARN) of the load balancer.
#'
#' @section Request syntax:
#' ```
#' svc$describe_load_balancer_attributes(
#'   LoadBalancerArn = "string"
#' )
#' ```
#'
#' @examples
#' # This example describes the attributes of the specified load balancer.
#' \donttest{svc$describe_load_balancer_attributes(
#'   LoadBalancerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_load_balancer_attributes
elbv2_describe_load_balancer_attributes <- function(LoadBalancerArn) {
  op <- new_operation(
    name = "DescribeLoadBalancerAttributes",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_load_balancer_attributes_input(LoadBalancerArn = LoadBalancerArn)
  output <- .elbv2$describe_load_balancer_attributes_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_load_balancer_attributes <- elbv2_describe_load_balancer_attributes

#' Describes the specified load balancers or all of your load balancers
#'
#' Describes the specified load balancers or all of your load balancers.
#' 
#' To describe the listeners for a load balancer, use DescribeListeners. To
#' describe the attributes for a load balancer, use
#' DescribeLoadBalancerAttributes.
#'
#' @usage
#' elbv2_describe_load_balancers(LoadBalancerArns, Names, Marker, PageSize)
#'
#' @param LoadBalancerArns The Amazon Resource Names (ARN) of the load balancers. You can specify
#' up to 20 load balancers in a single call.
#' @param Names The names of the load balancers.
#' @param Marker The marker for the next set of results. (You received this marker from a
#' previous call.)
#' @param PageSize The maximum number of results to return with this call.
#'
#' @section Request syntax:
#' ```
#' svc$describe_load_balancers(
#'   LoadBalancerArns = list(
#'     "string"
#'   ),
#'   Names = list(
#'     "string"
#'   ),
#'   Marker = "string",
#'   PageSize = 123
#' )
#' ```
#'
#' @examples
#' # This example describes the specified load balancer.
#' \donttest{svc$describe_load_balancers(
#'   LoadBalancerArns = list(
#'     "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my-load-balancer/5..."
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_load_balancers
elbv2_describe_load_balancers <- function(LoadBalancerArns = NULL, Names = NULL, Marker = NULL, PageSize = NULL) {
  op <- new_operation(
    name = "DescribeLoadBalancers",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_load_balancers_input(LoadBalancerArns = LoadBalancerArns, Names = Names, Marker = Marker, PageSize = PageSize)
  output <- .elbv2$describe_load_balancers_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_load_balancers <- elbv2_describe_load_balancers

#' Describes the specified rules or the rules for the specified listener
#'
#' Describes the specified rules or the rules for the specified listener.
#' You must specify either a listener or one or more rules.
#'
#' @usage
#' elbv2_describe_rules(ListenerArn, RuleArns, Marker, PageSize)
#'
#' @param ListenerArn The Amazon Resource Name (ARN) of the listener.
#' @param RuleArns The Amazon Resource Names (ARN) of the rules.
#' @param Marker The marker for the next set of results. (You received this marker from a
#' previous call.)
#' @param PageSize The maximum number of results to return with this call.
#'
#' @section Request syntax:
#' ```
#' svc$describe_rules(
#'   ListenerArn = "string",
#'   RuleArns = list(
#'     "string"
#'   ),
#'   Marker = "string",
#'   PageSize = 123
#' )
#' ```
#'
#' @examples
#' # This example describes the specified rule.
#' \donttest{svc$describe_rules(
#'   RuleArns = list(
#'     "arn:aws:elasticloadbalancing:us-west-2:123456789012:listener-rule/app/my-load-balancer/..."
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_rules
elbv2_describe_rules <- function(ListenerArn = NULL, RuleArns = NULL, Marker = NULL, PageSize = NULL) {
  op <- new_operation(
    name = "DescribeRules",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_rules_input(ListenerArn = ListenerArn, RuleArns = RuleArns, Marker = Marker, PageSize = PageSize)
  output <- .elbv2$describe_rules_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_rules <- elbv2_describe_rules

#' Describes the specified policies or all policies used for SSL
#' negotiation
#'
#' Describes the specified policies or all policies used for SSL
#' negotiation.
#' 
#' For more information, see [Security
#' Policies](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/create-https-listener.html#describe-ssl-policies)
#' in the *Application Load Balancers Guide*.
#'
#' @usage
#' elbv2_describe_ssl_policies(Names, Marker, PageSize)
#'
#' @param Names The names of the policies.
#' @param Marker The marker for the next set of results. (You received this marker from a
#' previous call.)
#' @param PageSize The maximum number of results to return with this call.
#'
#' @section Request syntax:
#' ```
#' svc$describe_ssl_policies(
#'   Names = list(
#'     "string"
#'   ),
#'   Marker = "string",
#'   PageSize = 123
#' )
#' ```
#'
#' @examples
#' # This example describes the specified policy used for SSL negotiation.
#' \donttest{svc$describe_ssl_policies(
#'   Names = list(
#'     "ELBSecurityPolicy-2015-05"
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_ssl_policies
elbv2_describe_ssl_policies <- function(Names = NULL, Marker = NULL, PageSize = NULL) {
  op <- new_operation(
    name = "DescribeSSLPolicies",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_ssl_policies_input(Names = Names, Marker = Marker, PageSize = PageSize)
  output <- .elbv2$describe_ssl_policies_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_ssl_policies <- elbv2_describe_ssl_policies

#' Describes the tags for the specified resources
#'
#' Describes the tags for the specified resources. You can describe the
#' tags for one or more Application Load Balancers, Network Load Balancers,
#' and target groups.
#'
#' @usage
#' elbv2_describe_tags(ResourceArns)
#'
#' @param ResourceArns &#91;required&#93; The Amazon Resource Names (ARN) of the resources.
#'
#' @section Request syntax:
#' ```
#' svc$describe_tags(
#'   ResourceArns = list(
#'     "string"
#'   )
#' )
#' ```
#'
#' @examples
#' # This example describes the tags assigned to the specified load balancer.
#' \donttest{svc$describe_tags(
#'   ResourceArns = list(
#'     "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my-load-balancer/5..."
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_tags
elbv2_describe_tags <- function(ResourceArns) {
  op <- new_operation(
    name = "DescribeTags",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_tags_input(ResourceArns = ResourceArns)
  output <- .elbv2$describe_tags_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_tags <- elbv2_describe_tags

#' Describes the attributes for the specified target group
#'
#' Describes the attributes for the specified target group.
#' 
#' For more information, see [Target Group
#' Attributes](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-target-groups.html#target-group-attributes)
#' in the *Application Load Balancers Guide* or [Target Group
#' Attributes](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-target-groups.html#target-group-attributes)
#' in the *Network Load Balancers Guide*.
#'
#' @usage
#' elbv2_describe_target_group_attributes(TargetGroupArn)
#'
#' @param TargetGroupArn &#91;required&#93; The Amazon Resource Name (ARN) of the target group.
#'
#' @section Request syntax:
#' ```
#' svc$describe_target_group_attributes(
#'   TargetGroupArn = "string"
#' )
#' ```
#'
#' @examples
#' # This example describes the attributes of the specified target group.
#' \donttest{svc$describe_target_group_attributes(
#'   TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targe..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_target_group_attributes
elbv2_describe_target_group_attributes <- function(TargetGroupArn) {
  op <- new_operation(
    name = "DescribeTargetGroupAttributes",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_target_group_attributes_input(TargetGroupArn = TargetGroupArn)
  output <- .elbv2$describe_target_group_attributes_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_target_group_attributes <- elbv2_describe_target_group_attributes

#' Describes the specified target groups or all of your target groups
#'
#' Describes the specified target groups or all of your target groups. By
#' default, all target groups are described. Alternatively, you can specify
#' one of the following to filter the results: the ARN of the load
#' balancer, the names of one or more target groups, or the ARNs of one or
#' more target groups.
#' 
#' To describe the targets for a target group, use DescribeTargetHealth. To
#' describe the attributes of a target group, use
#' DescribeTargetGroupAttributes.
#'
#' @usage
#' elbv2_describe_target_groups(LoadBalancerArn, TargetGroupArns, Names,
#'   Marker, PageSize)
#'
#' @param LoadBalancerArn The Amazon Resource Name (ARN) of the load balancer.
#' @param TargetGroupArns The Amazon Resource Names (ARN) of the target groups.
#' @param Names The names of the target groups.
#' @param Marker The marker for the next set of results. (You received this marker from a
#' previous call.)
#' @param PageSize The maximum number of results to return with this call.
#'
#' @section Request syntax:
#' ```
#' svc$describe_target_groups(
#'   LoadBalancerArn = "string",
#'   TargetGroupArns = list(
#'     "string"
#'   ),
#'   Names = list(
#'     "string"
#'   ),
#'   Marker = "string",
#'   PageSize = 123
#' )
#' ```
#'
#' @examples
#' # This example describes the specified target group.
#' \donttest{svc$describe_target_groups(
#'   TargetGroupArns = list(
#'     "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targets/73e2d6bc24d8..."
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_target_groups
elbv2_describe_target_groups <- function(LoadBalancerArn = NULL, TargetGroupArns = NULL, Names = NULL, Marker = NULL, PageSize = NULL) {
  op <- new_operation(
    name = "DescribeTargetGroups",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_target_groups_input(LoadBalancerArn = LoadBalancerArn, TargetGroupArns = TargetGroupArns, Names = Names, Marker = Marker, PageSize = PageSize)
  output <- .elbv2$describe_target_groups_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_target_groups <- elbv2_describe_target_groups

#' Describes the health of the specified targets or all of your targets
#'
#' Describes the health of the specified targets or all of your targets.
#'
#' @usage
#' elbv2_describe_target_health(TargetGroupArn, Targets)
#'
#' @param TargetGroupArn &#91;required&#93; The Amazon Resource Name (ARN) of the target group.
#' @param Targets The targets.
#'
#' @section Request syntax:
#' ```
#' svc$describe_target_health(
#'   TargetGroupArn = "string",
#'   Targets = list(
#'     list(
#'       Id = "string",
#'       Port = 123,
#'       AvailabilityZone = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example describes the health of the targets for the specified
#' # target group. One target is healthy but the other is not specified in an
#' # action, so it can't receive traffic from the load balancer.
#' \donttest{svc$describe_target_health(
#'   TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targe..."
#' )}
#' 
#' # This example describes the health of the specified target. This target
#' # is healthy.
#' \donttest{svc$describe_target_health(
#'   TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targe...",
#'   Targets = list(
#'     list(
#'       Id = "i-0f76fade",
#'       Port = 80L
#'     )
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_describe_target_health
elbv2_describe_target_health <- function(TargetGroupArn, Targets = NULL) {
  op <- new_operation(
    name = "DescribeTargetHealth",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$describe_target_health_input(TargetGroupArn = TargetGroupArn, Targets = Targets)
  output <- .elbv2$describe_target_health_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$describe_target_health <- elbv2_describe_target_health

#' Replaces the specified properties of the specified listener
#'
#' Replaces the specified properties of the specified listener. Any
#' properties that you do not specify remain unchanged.
#' 
#' Changing the protocol from HTTPS to HTTP, or from TLS to TCP, removes
#' the security policy and default certificate properties. If you change
#' the protocol from HTTP to HTTPS, or from TCP to TLS, you must add the
#' security policy and default certificate properties.
#' 
#' To add an item to a list, remove an item from a list, or update an item
#' in a list, you must provide the entire list. For example, to add an
#' action, specify a list with the current actions plus the new action.
#'
#' @usage
#' elbv2_modify_listener(ListenerArn, Port, Protocol, SslPolicy,
#'   Certificates, DefaultActions)
#'
#' @param ListenerArn &#91;required&#93; The Amazon Resource Name (ARN) of the listener.
#' @param Port The port for connections from clients to the load balancer.
#' @param Protocol The protocol for connections from clients to the load balancer.
#' Application Load Balancers support the HTTP and HTTPS protocols. Network
#' Load Balancers support the TCP, TLS, UDP, and TCP\\_UDP protocols.
#' @param SslPolicy \[HTTPS and TLS listeners\] The security policy that defines which
#' protocols and ciphers are supported. For more information, see [Security
#' Policies](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/create-https-listener.html#describe-ssl-policies)
#' in the *Application Load Balancers Guide*.
#' @param Certificates \[HTTPS and TLS listeners\] The default certificate for the listener.
#' You must provide exactly one certificate. Set `CertificateArn` to the
#' certificate ARN but do not set `IsDefault`.
#' 
#' To create a certificate list, use AddListenerCertificates.
#' @param DefaultActions The actions for the default rule. The rule must include one forward
#' action or one or more fixed-response actions.
#' 
#' If the action type is `forward`, you specify one or more target groups.
#' The protocol of the target group must be HTTP or HTTPS for an
#' Application Load Balancer. The protocol of the target group must be TCP,
#' TLS, UDP, or TCP\\_UDP for a Network Load Balancer.
#' 
#' \[HTTPS listeners\] If the action type is `authenticate-oidc`, you
#' authenticate users through an identity provider that is OpenID Connect
#' (OIDC) compliant.
#' 
#' \[HTTPS listeners\] If the action type is `authenticate-cognito`, you
#' authenticate users through the user pools supported by Amazon Cognito.
#' 
#' \[Application Load Balancer\] If the action type is `redirect`, you
#' redirect specified client requests from one URL to another.
#' 
#' \[Application Load Balancer\] If the action type is `fixed-response`,
#' you drop specified client requests and return a custom HTTP response.
#'
#' @section Request syntax:
#' ```
#' svc$modify_listener(
#'   ListenerArn = "string",
#'   Port = 123,
#'   Protocol = "HTTP"|"HTTPS"|"TCP"|"TLS"|"UDP"|"TCP_UDP",
#'   SslPolicy = "string",
#'   Certificates = list(
#'     list(
#'       CertificateArn = "string",
#'       IsDefault = TRUE|FALSE
#'     )
#'   ),
#'   DefaultActions = list(
#'     list(
#'       Type = "forward"|"authenticate-oidc"|"authenticate-cognito"|"redirect"|"fixed-response",
#'       TargetGroupArn = "string",
#'       AuthenticateOidcConfig = list(
#'         Issuer = "string",
#'         AuthorizationEndpoint = "string",
#'         TokenEndpoint = "string",
#'         UserInfoEndpoint = "string",
#'         ClientId = "string",
#'         ClientSecret = "string",
#'         SessionCookieName = "string",
#'         Scope = "string",
#'         SessionTimeout = 123,
#'         AuthenticationRequestExtraParams = list(
#'           "string"
#'         ),
#'         OnUnauthenticatedRequest = "deny"|"allow"|"authenticate",
#'         UseExistingClientSecret = TRUE|FALSE
#'       ),
#'       AuthenticateCognitoConfig = list(
#'         UserPoolArn = "string",
#'         UserPoolClientId = "string",
#'         UserPoolDomain = "string",
#'         SessionCookieName = "string",
#'         Scope = "string",
#'         SessionTimeout = 123,
#'         AuthenticationRequestExtraParams = list(
#'           "string"
#'         ),
#'         OnUnauthenticatedRequest = "deny"|"allow"|"authenticate"
#'       ),
#'       Order = 123,
#'       RedirectConfig = list(
#'         Protocol = "string",
#'         Port = "string",
#'         Host = "string",
#'         Path = "string",
#'         Query = "string",
#'         StatusCode = "HTTP_301"|"HTTP_302"
#'       ),
#'       FixedResponseConfig = list(
#'         MessageBody = "string",
#'         StatusCode = "string",
#'         ContentType = "string"
#'       ),
#'       ForwardConfig = list(
#'         TargetGroups = list(
#'           list(
#'             TargetGroupArn = "string",
#'             Weight = 123
#'           )
#'         ),
#'         TargetGroupStickinessConfig = list(
#'           Enabled = TRUE|FALSE,
#'           DurationSeconds = 123
#'         )
#'       )
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example changes the default action for the specified listener.
#' \donttest{svc$modify_listener(
#'   DefaultActions = list(
#'     list(
#'       TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-n...",
#'       Type = "forward"
#'     )
#'   ),
#'   ListenerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:listener/app/my-load-ba..."
#' )}
#' 
#' # This example changes the server certificate for the specified HTTPS
#' # listener.
#' \donttest{svc$modify_listener(
#'   Certificates = list(
#'     list(
#'       CertificateArn = "arn:aws:iam::123456789012:server-certificate/my-new-server-cert"
#'     )
#'   ),
#'   ListenerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:listener/app/my-load-ba..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_modify_listener
elbv2_modify_listener <- function(ListenerArn, Port = NULL, Protocol = NULL, SslPolicy = NULL, Certificates = NULL, DefaultActions = NULL) {
  op <- new_operation(
    name = "ModifyListener",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$modify_listener_input(ListenerArn = ListenerArn, Port = Port, Protocol = Protocol, SslPolicy = SslPolicy, Certificates = Certificates, DefaultActions = DefaultActions)
  output <- .elbv2$modify_listener_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$modify_listener <- elbv2_modify_listener

#' Modifies the specified attributes of the specified Application Load
#' Balancer or Network Load Balancer
#'
#' Modifies the specified attributes of the specified Application Load
#' Balancer or Network Load Balancer.
#' 
#' If any of the specified attributes can\'t be modified as requested, the
#' call fails. Any existing attributes that you do not modify retain their
#' current values.
#'
#' @usage
#' elbv2_modify_load_balancer_attributes(LoadBalancerArn, Attributes)
#'
#' @param LoadBalancerArn &#91;required&#93; The Amazon Resource Name (ARN) of the load balancer.
#' @param Attributes &#91;required&#93; The load balancer attributes.
#'
#' @section Request syntax:
#' ```
#' svc$modify_load_balancer_attributes(
#'   LoadBalancerArn = "string",
#'   Attributes = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example enables deletion protection for the specified load
#' # balancer.
#' \donttest{svc$modify_load_balancer_attributes(
#'   Attributes = list(
#'     list(
#'       Key = "deletion_protection.enabled",
#'       Value = "true"
#'     )
#'   ),
#'   LoadBalancerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my..."
#' )}
#' 
#' # This example changes the idle timeout value for the specified load
#' # balancer.
#' \donttest{svc$modify_load_balancer_attributes(
#'   Attributes = list(
#'     list(
#'       Key = "idle_timeout.timeout_seconds",
#'       Value = "30"
#'     )
#'   ),
#'   LoadBalancerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my..."
#' )}
#' 
#' # This example enables access logs for the specified load balancer. Note
#' # that the S3 bucket must exist in the same region as the load balancer
#' # and must have a policy attached that grants access to the Elastic Load
#' # Balancing service.
#' \donttest{svc$modify_load_balancer_attributes(
#'   Attributes = list(
#'     list(
#'       Key = "access_logs.s3.enabled",
#'       Value = "true"
#'     ),
#'     list(
#'       Key = "access_logs.s3.bucket",
#'       Value = "my-loadbalancer-logs"
#'     ),
#'     list(
#'       Key = "access_logs.s3.prefix",
#'       Value = "myapp"
#'     )
#'   ),
#'   LoadBalancerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_modify_load_balancer_attributes
elbv2_modify_load_balancer_attributes <- function(LoadBalancerArn, Attributes) {
  op <- new_operation(
    name = "ModifyLoadBalancerAttributes",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$modify_load_balancer_attributes_input(LoadBalancerArn = LoadBalancerArn, Attributes = Attributes)
  output <- .elbv2$modify_load_balancer_attributes_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$modify_load_balancer_attributes <- elbv2_modify_load_balancer_attributes

#' Replaces the specified properties of the specified rule
#'
#' Replaces the specified properties of the specified rule. Any properties
#' that you do not specify are unchanged.
#' 
#' To add an item to a list, remove an item from a list, or update an item
#' in a list, you must provide the entire list. For example, to add an
#' action, specify a list with the current actions plus the new action.
#' 
#' To modify the actions for the default rule, use ModifyListener.
#'
#' @usage
#' elbv2_modify_rule(RuleArn, Conditions, Actions)
#'
#' @param RuleArn &#91;required&#93; The Amazon Resource Name (ARN) of the rule.
#' @param Conditions The conditions. Each rule can include zero or one of the following
#' conditions: `http-request-method`, `host-header`, `path-pattern`, and
#' `source-ip`, and zero or more of the following conditions: `http-header`
#' and `query-string`.
#' @param Actions The actions. Each rule must include exactly one of the following types
#' of actions: `forward`, `fixed-response`, or `redirect`, and it must be
#' the last action to be performed.
#' 
#' If the action type is `forward`, you specify one or more target groups.
#' The protocol of the target group must be HTTP or HTTPS for an
#' Application Load Balancer. The protocol of the target group must be TCP,
#' TLS, UDP, or TCP\\_UDP for a Network Load Balancer.
#' 
#' \[HTTPS listeners\] If the action type is `authenticate-oidc`, you
#' authenticate users through an identity provider that is OpenID Connect
#' (OIDC) compliant.
#' 
#' \[HTTPS listeners\] If the action type is `authenticate-cognito`, you
#' authenticate users through the user pools supported by Amazon Cognito.
#' 
#' \[Application Load Balancer\] If the action type is `redirect`, you
#' redirect specified client requests from one URL to another.
#' 
#' \[Application Load Balancer\] If the action type is `fixed-response`,
#' you drop specified client requests and return a custom HTTP response.
#'
#' @section Request syntax:
#' ```
#' svc$modify_rule(
#'   RuleArn = "string",
#'   Conditions = list(
#'     list(
#'       Field = "string",
#'       Values = list(
#'         "string"
#'       ),
#'       HostHeaderConfig = list(
#'         Values = list(
#'           "string"
#'         )
#'       ),
#'       PathPatternConfig = list(
#'         Values = list(
#'           "string"
#'         )
#'       ),
#'       HttpHeaderConfig = list(
#'         HttpHeaderName = "string",
#'         Values = list(
#'           "string"
#'         )
#'       ),
#'       QueryStringConfig = list(
#'         Values = list(
#'           list(
#'             Key = "string",
#'             Value = "string"
#'           )
#'         )
#'       ),
#'       HttpRequestMethodConfig = list(
#'         Values = list(
#'           "string"
#'         )
#'       ),
#'       SourceIpConfig = list(
#'         Values = list(
#'           "string"
#'         )
#'       )
#'     )
#'   ),
#'   Actions = list(
#'     list(
#'       Type = "forward"|"authenticate-oidc"|"authenticate-cognito"|"redirect"|"fixed-response",
#'       TargetGroupArn = "string",
#'       AuthenticateOidcConfig = list(
#'         Issuer = "string",
#'         AuthorizationEndpoint = "string",
#'         TokenEndpoint = "string",
#'         UserInfoEndpoint = "string",
#'         ClientId = "string",
#'         ClientSecret = "string",
#'         SessionCookieName = "string",
#'         Scope = "string",
#'         SessionTimeout = 123,
#'         AuthenticationRequestExtraParams = list(
#'           "string"
#'         ),
#'         OnUnauthenticatedRequest = "deny"|"allow"|"authenticate",
#'         UseExistingClientSecret = TRUE|FALSE
#'       ),
#'       AuthenticateCognitoConfig = list(
#'         UserPoolArn = "string",
#'         UserPoolClientId = "string",
#'         UserPoolDomain = "string",
#'         SessionCookieName = "string",
#'         Scope = "string",
#'         SessionTimeout = 123,
#'         AuthenticationRequestExtraParams = list(
#'           "string"
#'         ),
#'         OnUnauthenticatedRequest = "deny"|"allow"|"authenticate"
#'       ),
#'       Order = 123,
#'       RedirectConfig = list(
#'         Protocol = "string",
#'         Port = "string",
#'         Host = "string",
#'         Path = "string",
#'         Query = "string",
#'         StatusCode = "HTTP_301"|"HTTP_302"
#'       ),
#'       FixedResponseConfig = list(
#'         MessageBody = "string",
#'         StatusCode = "string",
#'         ContentType = "string"
#'       ),
#'       ForwardConfig = list(
#'         TargetGroups = list(
#'           list(
#'             TargetGroupArn = "string",
#'             Weight = 123
#'           )
#'         ),
#'         TargetGroupStickinessConfig = list(
#'           Enabled = TRUE|FALSE,
#'           DurationSeconds = 123
#'         )
#'       )
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example modifies the condition for the specified rule.
#' \donttest{svc$modify_rule(
#'   Conditions = list(
#'     list(
#'       Field = "path-pattern",
#'       Values = list(
#'         "/images/*"
#'       )
#'     )
#'   ),
#'   RuleArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:listener-rule/app/my-load-b..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_modify_rule
elbv2_modify_rule <- function(RuleArn, Conditions = NULL, Actions = NULL) {
  op <- new_operation(
    name = "ModifyRule",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$modify_rule_input(RuleArn = RuleArn, Conditions = Conditions, Actions = Actions)
  output <- .elbv2$modify_rule_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$modify_rule <- elbv2_modify_rule

#' Modifies the health checks used when evaluating the health state of the
#' targets in the specified target group
#'
#' Modifies the health checks used when evaluating the health state of the
#' targets in the specified target group.
#' 
#' To monitor the health of the targets, use DescribeTargetHealth.
#'
#' @usage
#' elbv2_modify_target_group(TargetGroupArn, HealthCheckProtocol,
#'   HealthCheckPort, HealthCheckPath, HealthCheckEnabled,
#'   HealthCheckIntervalSeconds, HealthCheckTimeoutSeconds,
#'   HealthyThresholdCount, UnhealthyThresholdCount, Matcher)
#'
#' @param TargetGroupArn &#91;required&#93; The Amazon Resource Name (ARN) of the target group.
#' @param HealthCheckProtocol The protocol the load balancer uses when performing health checks on
#' targets. The TCP protocol is supported for health checks only if the
#' protocol of the target group is TCP, TLS, UDP, or TCP\\_UDP. The TLS,
#' UDP, and TCP\\_UDP protocols are not supported for health checks.
#' 
#' With Network Load Balancers, you can\'t modify this setting.
#' @param HealthCheckPort The port the load balancer uses when performing health checks on
#' targets.
#' @param HealthCheckPath \[HTTP/HTTPS health checks\] The ping path that is the destination for
#' the health check request.
#' @param HealthCheckEnabled Indicates whether health checks are enabled.
#' @param HealthCheckIntervalSeconds The approximate amount of time, in seconds, between health checks of an
#' individual target. For Application Load Balancers, the range is 5 to 300
#' seconds. For Network Load Balancers, the supported values are 10 or 30
#' seconds.
#' 
#' With Network Load Balancers, you can\'t modify this setting.
#' @param HealthCheckTimeoutSeconds \[HTTP/HTTPS health checks\] The amount of time, in seconds, during
#' which no response means a failed health check.
#' 
#' With Network Load Balancers, you can\'t modify this setting.
#' @param HealthyThresholdCount The number of consecutive health checks successes required before
#' considering an unhealthy target healthy.
#' @param UnhealthyThresholdCount The number of consecutive health check failures required before
#' considering the target unhealthy. For Network Load Balancers, this value
#' must be the same as the healthy threshold count.
#' @param Matcher \[HTTP/HTTPS health checks\] The HTTP codes to use when checking for a
#' successful response from a target.
#' 
#' With Network Load Balancers, you can\'t modify this setting.
#'
#' @section Request syntax:
#' ```
#' svc$modify_target_group(
#'   TargetGroupArn = "string",
#'   HealthCheckProtocol = "HTTP"|"HTTPS"|"TCP"|"TLS"|"UDP"|"TCP_UDP",
#'   HealthCheckPort = "string",
#'   HealthCheckPath = "string",
#'   HealthCheckEnabled = TRUE|FALSE,
#'   HealthCheckIntervalSeconds = 123,
#'   HealthCheckTimeoutSeconds = 123,
#'   HealthyThresholdCount = 123,
#'   UnhealthyThresholdCount = 123,
#'   Matcher = list(
#'     HttpCode = "string"
#'   )
#' )
#' ```
#'
#' @examples
#' # This example changes the configuration of the health checks used to
#' # evaluate the health of the targets for the specified target group.
#' \donttest{svc$modify_target_group(
#'   HealthCheckPort = "443",
#'   HealthCheckProtocol = "HTTPS",
#'   TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-https..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_modify_target_group
elbv2_modify_target_group <- function(TargetGroupArn, HealthCheckProtocol = NULL, HealthCheckPort = NULL, HealthCheckPath = NULL, HealthCheckEnabled = NULL, HealthCheckIntervalSeconds = NULL, HealthCheckTimeoutSeconds = NULL, HealthyThresholdCount = NULL, UnhealthyThresholdCount = NULL, Matcher = NULL) {
  op <- new_operation(
    name = "ModifyTargetGroup",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$modify_target_group_input(TargetGroupArn = TargetGroupArn, HealthCheckProtocol = HealthCheckProtocol, HealthCheckPort = HealthCheckPort, HealthCheckPath = HealthCheckPath, HealthCheckEnabled = HealthCheckEnabled, HealthCheckIntervalSeconds = HealthCheckIntervalSeconds, HealthCheckTimeoutSeconds = HealthCheckTimeoutSeconds, HealthyThresholdCount = HealthyThresholdCount, UnhealthyThresholdCount = UnhealthyThresholdCount, Matcher = Matcher)
  output <- .elbv2$modify_target_group_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$modify_target_group <- elbv2_modify_target_group

#' Modifies the specified attributes of the specified target group
#'
#' Modifies the specified attributes of the specified target group.
#'
#' @usage
#' elbv2_modify_target_group_attributes(TargetGroupArn, Attributes)
#'
#' @param TargetGroupArn &#91;required&#93; The Amazon Resource Name (ARN) of the target group.
#' @param Attributes &#91;required&#93; The attributes.
#'
#' @section Request syntax:
#' ```
#' svc$modify_target_group_attributes(
#'   TargetGroupArn = "string",
#'   Attributes = list(
#'     list(
#'       Key = "string",
#'       Value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example sets the deregistration delay timeout to the specified
#' # value for the specified target group.
#' \donttest{svc$modify_target_group_attributes(
#'   Attributes = list(
#'     list(
#'       Key = "deregistration_delay.timeout_seconds",
#'       Value = "600"
#'     )
#'   ),
#'   TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targe..."
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_modify_target_group_attributes
elbv2_modify_target_group_attributes <- function(TargetGroupArn, Attributes) {
  op <- new_operation(
    name = "ModifyTargetGroupAttributes",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$modify_target_group_attributes_input(TargetGroupArn = TargetGroupArn, Attributes = Attributes)
  output <- .elbv2$modify_target_group_attributes_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$modify_target_group_attributes <- elbv2_modify_target_group_attributes

#' Registers the specified targets with the specified target group
#'
#' Registers the specified targets with the specified target group.
#' 
#' If the target is an EC2 instance, it must be in the `running` state when
#' you register it.
#' 
#' By default, the load balancer routes requests to registered targets
#' using the protocol and port for the target group. Alternatively, you can
#' override the port for a target when you register it. You can register
#' each EC2 instance or IP address with the same target group multiple
#' times using different ports.
#' 
#' With a Network Load Balancer, you cannot register instances by instance
#' ID if they have the following instance types: C1, CC1, CC2, CG1, CG2,
#' CR1, CS1, G1, G2, HI1, HS1, M1, M2, M3, and T1. You can register
#' instances of these types by IP address.
#' 
#' To remove a target from a target group, use DeregisterTargets.
#'
#' @usage
#' elbv2_register_targets(TargetGroupArn, Targets)
#'
#' @param TargetGroupArn &#91;required&#93; The Amazon Resource Name (ARN) of the target group.
#' @param Targets &#91;required&#93; The targets.
#' 
#' To register a target by instance ID, specify the instance ID. To
#' register a target by IP address, specify the IP address. To register a
#' Lambda function, specify the ARN of the Lambda function.
#'
#' @section Request syntax:
#' ```
#' svc$register_targets(
#'   TargetGroupArn = "string",
#'   Targets = list(
#'     list(
#'       Id = "string",
#'       Port = 123,
#'       AvailabilityZone = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example registers the specified instances with the specified target
#' # group.
#' \donttest{svc$register_targets(
#'   TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targe...",
#'   Targets = list(
#'     list(
#'       Id = "i-80c8dd94"
#'     ),
#'     list(
#'       Id = "i-ceddcd4d"
#'     )
#'   )
#' )}
#' 
#' # This example registers the specified instance with the specified target
#' # group using multiple ports. This enables you to register ECS containers
#' # on the same instance as targets in the target group.
#' \donttest{svc$register_targets(
#'   TargetGroupArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-new-t...",
#'   Targets = list(
#'     list(
#'       Id = "i-80c8dd94",
#'       Port = 80L
#'     ),
#'     list(
#'       Id = "i-80c8dd94",
#'       Port = 766L
#'     )
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_register_targets
elbv2_register_targets <- function(TargetGroupArn, Targets) {
  op <- new_operation(
    name = "RegisterTargets",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$register_targets_input(TargetGroupArn = TargetGroupArn, Targets = Targets)
  output <- .elbv2$register_targets_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$register_targets <- elbv2_register_targets

#' Removes the specified certificate from the certificate list for the
#' specified HTTPS or TLS listener
#'
#' Removes the specified certificate from the certificate list for the
#' specified HTTPS or TLS listener.
#' 
#' You can\'t remove the default certificate for a listener. To replace the
#' default certificate, call ModifyListener.
#' 
#' To list the certificates for your listener, use
#' DescribeListenerCertificates.
#'
#' @usage
#' elbv2_remove_listener_certificates(ListenerArn, Certificates)
#'
#' @param ListenerArn &#91;required&#93; The Amazon Resource Name (ARN) of the listener.
#' @param Certificates &#91;required&#93; The certificate to remove. You can specify one certificate per call. Set
#' `CertificateArn` to the certificate ARN but do not set `IsDefault`.
#'
#' @section Request syntax:
#' ```
#' svc$remove_listener_certificates(
#'   ListenerArn = "string",
#'   Certificates = list(
#'     list(
#'       CertificateArn = "string",
#'       IsDefault = TRUE|FALSE
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname elbv2_remove_listener_certificates
elbv2_remove_listener_certificates <- function(ListenerArn, Certificates) {
  op <- new_operation(
    name = "RemoveListenerCertificates",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$remove_listener_certificates_input(ListenerArn = ListenerArn, Certificates = Certificates)
  output <- .elbv2$remove_listener_certificates_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$remove_listener_certificates <- elbv2_remove_listener_certificates

#' Removes the specified tags from the specified Elastic Load Balancing
#' resource
#'
#' Removes the specified tags from the specified Elastic Load Balancing
#' resource.
#' 
#' To list the current tags for your resources, use DescribeTags.
#'
#' @usage
#' elbv2_remove_tags(ResourceArns, TagKeys)
#'
#' @param ResourceArns &#91;required&#93; The Amazon Resource Name (ARN) of the resource.
#' @param TagKeys &#91;required&#93; The tag keys for the tags to remove.
#'
#' @section Request syntax:
#' ```
#' svc$remove_tags(
#'   ResourceArns = list(
#'     "string"
#'   ),
#'   TagKeys = list(
#'     "string"
#'   )
#' )
#' ```
#'
#' @examples
#' # This example removes the specified tags from the specified load
#' # balancer.
#' \donttest{svc$remove_tags(
#'   ResourceArns = list(
#'     "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my-load-balancer/5..."
#'   ),
#'   TagKeys = list(
#'     "project",
#'     "department"
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_remove_tags
elbv2_remove_tags <- function(ResourceArns, TagKeys) {
  op <- new_operation(
    name = "RemoveTags",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$remove_tags_input(ResourceArns = ResourceArns, TagKeys = TagKeys)
  output <- .elbv2$remove_tags_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$remove_tags <- elbv2_remove_tags

#' Sets the type of IP addresses used by the subnets of the specified
#' Application Load Balancer or Network Load Balancer
#'
#' Sets the type of IP addresses used by the subnets of the specified
#' Application Load Balancer or Network Load Balancer.
#'
#' @usage
#' elbv2_set_ip_address_type(LoadBalancerArn, IpAddressType)
#'
#' @param LoadBalancerArn &#91;required&#93; The Amazon Resource Name (ARN) of the load balancer.
#' @param IpAddressType &#91;required&#93; The IP address type. The possible values are `ipv4` (for IPv4 addresses)
#' and `dualstack` (for IPv4 and IPv6 addresses). Internal load balancers
#' must use `ipv4`. Network Load Balancers must use `ipv4`.
#'
#' @section Request syntax:
#' ```
#' svc$set_ip_address_type(
#'   LoadBalancerArn = "string",
#'   IpAddressType = "ipv4"|"dualstack"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname elbv2_set_ip_address_type
elbv2_set_ip_address_type <- function(LoadBalancerArn, IpAddressType) {
  op <- new_operation(
    name = "SetIpAddressType",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$set_ip_address_type_input(LoadBalancerArn = LoadBalancerArn, IpAddressType = IpAddressType)
  output <- .elbv2$set_ip_address_type_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$set_ip_address_type <- elbv2_set_ip_address_type

#' Sets the priorities of the specified rules
#'
#' Sets the priorities of the specified rules.
#' 
#' You can reorder the rules as long as there are no priority conflicts in
#' the new order. Any existing rules that you do not specify retain their
#' current priority.
#'
#' @usage
#' elbv2_set_rule_priorities(RulePriorities)
#'
#' @param RulePriorities &#91;required&#93; The rule priorities.
#'
#' @section Request syntax:
#' ```
#' svc$set_rule_priorities(
#'   RulePriorities = list(
#'     list(
#'       RuleArn = "string",
#'       Priority = 123
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example sets the priority of the specified rule.
#' \donttest{svc$set_rule_priorities(
#'   RulePriorities = list(
#'     list(
#'       Priority = 5L,
#'       RuleArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:listener-rule/app/my-lo..."
#'     )
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_set_rule_priorities
elbv2_set_rule_priorities <- function(RulePriorities) {
  op <- new_operation(
    name = "SetRulePriorities",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$set_rule_priorities_input(RulePriorities = RulePriorities)
  output <- .elbv2$set_rule_priorities_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$set_rule_priorities <- elbv2_set_rule_priorities

#' Associates the specified security groups with the specified Application
#' Load Balancer
#'
#' Associates the specified security groups with the specified Application
#' Load Balancer. The specified security groups override the previously
#' associated security groups.
#' 
#' You can\'t specify a security group for a Network Load Balancer.
#'
#' @usage
#' elbv2_set_security_groups(LoadBalancerArn, SecurityGroups)
#'
#' @param LoadBalancerArn &#91;required&#93; The Amazon Resource Name (ARN) of the load balancer.
#' @param SecurityGroups &#91;required&#93; The IDs of the security groups.
#'
#' @section Request syntax:
#' ```
#' svc$set_security_groups(
#'   LoadBalancerArn = "string",
#'   SecurityGroups = list(
#'     "string"
#'   )
#' )
#' ```
#'
#' @examples
#' # This example associates the specified security group with the specified
#' # load balancer.
#' \donttest{svc$set_security_groups(
#'   LoadBalancerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my...",
#'   SecurityGroups = list(
#'     "sg-5943793c"
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_set_security_groups
elbv2_set_security_groups <- function(LoadBalancerArn, SecurityGroups) {
  op <- new_operation(
    name = "SetSecurityGroups",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$set_security_groups_input(LoadBalancerArn = LoadBalancerArn, SecurityGroups = SecurityGroups)
  output <- .elbv2$set_security_groups_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$set_security_groups <- elbv2_set_security_groups

#' Enables the Availability Zones for the specified public subnets for the
#' specified load balancer
#'
#' Enables the Availability Zones for the specified public subnets for the
#' specified load balancer. The specified subnets replace the previously
#' enabled subnets.
#' 
#' When you specify subnets for a Network Load Balancer, you must include
#' all subnets that were enabled previously, with their existing
#' configurations, plus any additional subnets.
#'
#' @usage
#' elbv2_set_subnets(LoadBalancerArn, Subnets, SubnetMappings)
#'
#' @param LoadBalancerArn &#91;required&#93; The Amazon Resource Name (ARN) of the load balancer.
#' @param Subnets The IDs of the public subnets. You must specify subnets from at least
#' two Availability Zones. You can specify only one subnet per Availability
#' Zone. You must specify either subnets or subnet mappings.
#' @param SubnetMappings The IDs of the public subnets. You can specify only one subnet per
#' Availability Zone. You must specify either subnets or subnet mappings.
#' 
#' \[Application Load Balancers\] You must specify subnets from at least
#' two Availability Zones. You cannot specify Elastic IP addresses for your
#' subnets.
#' 
#' \[Network Load Balancers\] You can specify subnets from one or more
#' Availability Zones. If you need static IP addresses for your
#' internet-facing load balancer, you can specify one Elastic IP address
#' per subnet. For internal load balancers, you can specify one private IP
#' address per subnet from the IPv4 range of the subnet.
#'
#' @section Request syntax:
#' ```
#' svc$set_subnets(
#'   LoadBalancerArn = "string",
#'   Subnets = list(
#'     "string"
#'   ),
#'   SubnetMappings = list(
#'     list(
#'       SubnetId = "string",
#'       AllocationId = "string",
#'       PrivateIPv4Address = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @examples
#' # This example enables the Availability Zones for the specified subnets
#' # for the specified load balancer.
#' \donttest{svc$set_subnets(
#'   LoadBalancerArn = "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my...",
#'   Subnets = list(
#'     "subnet-8360a9e7",
#'     "subnet-b7d581c0"
#'   )
#' )}
#'
#' @keywords internal
#'
#' @rdname elbv2_set_subnets
elbv2_set_subnets <- function(LoadBalancerArn, Subnets = NULL, SubnetMappings = NULL) {
  op <- new_operation(
    name = "SetSubnets",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .elbv2$set_subnets_input(LoadBalancerArn = LoadBalancerArn, Subnets = Subnets, SubnetMappings = SubnetMappings)
  output <- .elbv2$set_subnets_output()
  config <- get_config()
  svc <- .elbv2$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.elbv2$operations$set_subnets <- elbv2_set_subnets
